pub struct BridgeSender { /* private fields */ }Expand description
Handle for the CDP server to send commands to the main thread.
Implementations
Sourceimpl BridgeSender
impl BridgeSender
Sourcepub fn send(&self, command: BridgeCommand) -> BridgeResponse
pub fn send(&self, command: BridgeCommand) -> BridgeResponse
Send a command to the main thread and wait for the response.
Sourcepub fn send_fire_and_forget(&self, command: BridgeCommand)
pub fn send_fire_and_forget(&self, command: BridgeCommand)
Send a command without waiting for response (fire-and-forget).