pub struct ScreenDisplayConfig {
pub width: u32,
pub height: u32,
pub color_depth: u32,
pub device_pixel_ratio: f64,
}Expand description
Screen/Display fingerprint configuration. Overrides screen dimensions, color depth, and device pixel ratio beyond what ScreenProfile already provides (this adds the JS injection that runs at the prototype level to resist dynamic queries).
Fields
width: u32height: u32color_depth: u32device_pixel_ratio: f64Trait Implementations
Sourceimpl Clone for ScreenDisplayConfig
impl Clone for ScreenDisplayConfig
Sourcefn clone(&self) -> ScreenDisplayConfig
fn clone(&self) -> ScreenDisplayConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScreenDisplayConfig
impl Debug for ScreenDisplayConfig
Sourceimpl Default for ScreenDisplayConfig
impl Default for ScreenDisplayConfig
Sourcefn default() -> ScreenDisplayConfig
fn default() -> ScreenDisplayConfig
Returns the “default value” for a type. Read more